summaryrefslogtreecommitdiffstats
path: root/lisp
diff options
context:
space:
mode:
authorClaudio Fontana <sick_soul@users.sourceforge.net>2006-01-06 04:52:00 +0000
committerClaudio Fontana <sick_soul@users.sourceforge.net>2006-01-06 04:52:00 +0000
commitb5b7b0baf551299e058432d58d5ab2e21d16c312 (patch)
treef0535089c67a6d6fdd746532953007253dd08cdb /lisp
parenta15c29c1a101a6bedc1a0ee5f6efd694a1ff4cad (diff)
downloadidutils-b5b7b0baf551299e058432d58d5ab2e21d16c312.tar.gz
idutils-b5b7b0baf551299e058432d58d5ab2e21d16c312.tar.bz2
idutils-b5b7b0baf551299e058432d58d5ab2e21d16c312.zip
* s/id-utils/idutils/g;
* other small changes
Diffstat (limited to 'lisp')
-rw-r--r--lisp/Makefile.am2
-rw-r--r--lisp/Makefile.in6
-rw-r--r--lisp/idutils.el (renamed from lisp/id-utils.el)16
3 files changed, 13 insertions, 11 deletions
diff --git a/lisp/Makefile.am b/lisp/Makefile.am
index 9038f21..16cf288 100644
--- a/lisp/Makefile.am
+++ b/lisp/Makefile.am
@@ -1,4 +1,4 @@
## Process this file with automake to create Makefile.in
-dist_lisp_LISP = id-utils.el
+dist_lisp_LISP = idutils.el
diff --git a/lisp/Makefile.in b/lisp/Makefile.in
index f91faef..06588ed 100644
--- a/lisp/Makefile.in
+++ b/lisp/Makefile.in
@@ -93,7 +93,7 @@ am__strip_dir = `echo $$p | sed -e 's|^.*/||'`;
am__installdirs = "$(DESTDIR)$(lispdir)"
dist_lispLISP_INSTALL = $(INSTALL_DATA)
LISP = $(dist_lisp_LISP)
-am__ELFILES = id-utils.el
+am__ELFILES = idutils.el
am__ELCFILES = $(am__ELFILES:.el=.elc)
ELCFILES = $(LISP:.el=.elc)
elisp_comp = $(top_srcdir)/elisp-comp
@@ -131,6 +131,8 @@ GENCAT = @GENCAT@
GETOPT_H = @GETOPT_H@
GLIBC2 = @GLIBC2@
GLIBC21 = @GLIBC21@
+GL_COND_LIBTOOL_FALSE = @GL_COND_LIBTOOL_FALSE@
+GL_COND_LIBTOOL_TRUE = @GL_COND_LIBTOOL_TRUE@
GMSGFMT = @GMSGFMT@
HAVE_ASPRINTF = @HAVE_ASPRINTF@
HAVE_POSIX_PRINTF = @HAVE_POSIX_PRINTF@
@@ -220,7 +222,7 @@ sbindir = @sbindir@
sharedstatedir = @sharedstatedir@
sysconfdir = @sysconfdir@
target_alias = @target_alias@
-dist_lisp_LISP = id-utils.el
+dist_lisp_LISP = idutils.el
all: all-am
.SUFFIXES:
diff --git a/lisp/id-utils.el b/lisp/idutils.el
index 09c7f9b..b52e614 100644
--- a/lisp/id-utils.el
+++ b/lisp/idutils.el
@@ -1,15 +1,15 @@
;;; id-utils.el -- emacs interface to `lid -R grep', a.k.a. `gid'
;;; Copyright (C) 1995, 1996 Free Software Foundation, Inc.
;;; Greg McGary <gkm@gnu.ai.mit.edu>.
;; This file is part of GNU id-utils.
;; GNU id-utils is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.
;; GNU id-utils is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
;; GNU General Public License for more details.
@@ -20,19 +20,19 @@
;; MA 02111-1307, USA.
;;; This package provides the tools meant to help editing PO files,
;;; as documented in the GNU id-utils user's manual. See this manual
;;; for user documentation, which is not repeated here.
;;; To install, merely put this file somewhere GNU Emacs will find it,
;;; then add the following lines to your .emacs file:
;;;
-;;; (autoload 'gid "id-utils")
+;;; (autoload 'gid "idutils")
;;;
;;; You may also adjust some customizations variables, below, by defining
;;; them in your .emacs file.
(require 'compile)
-(provide 'id-utils)
+(provide 'idutils)
(defvar gid-command "gid" "The command run by the gid function.")
@@ -1,15 +1,15 @@
-;;; id-utils.el -- emacs interface to `lid -R grep', a.k.a. `gid'
-;;; Copyright (C) 1995, 1996 Free Software Foundation, Inc.
+;;; idutils.el -- emacs interface to `lid -R grep', a.k.a. `gid'
+;;; Copyright (C) 1995, 1996, 2006 Free Software Foundation, Inc.
;;; Greg McGary <gkm@gnu.ai.mit.edu>.
@@ -1,15 +1,15 @@
;;; Greg McGary <gkm@gnu.ai.mit.edu>.
-;; This file is part of GNU id-utils.
+;; This file is part of GNU idutils.
-;; GNU id-utils is free software; you can redistribute it and/or modify
+;; GNU idutils is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
@@ -1,15 +1,15 @@
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.
-;; GNU id-utils is distributed in the hope that it will be useful,
+;; GNU idutils is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -20,19 +20,19 @@
;; MA 02111-1307, USA.
;;; This package provides the tools meant to help editing PO files,
-;;; as documented in the GNU id-utils user's manual. See this manual
+;;; as documented in the GNU idutils user's manual. See this manual
;;; for user documentation, which is not repeated here.
;;; To install, merely put this file somewhere GNU Emacs will find it,